@@ -21,6 +21,6 @@ if (suppressWarnings(
   })
 
   test_that("ggemmeans, lmrob", {
-    expect_error(ggemmeans(m1, "c12hour"))
+    expect_null(ggemmeans(m1, "c12hour"))
   })
 }
